@@ -10,17 +10,15 @@
 package DBI::Const::GetInfoReturn;
 
 use strict;
+use warnings;
 
 use Exporter ();
 
-use vars qw(@ISA @EXPORT @EXPORT_OK %GetInfoReturnTypes %GetInfoReturnValues);
-
-@ISA = qw(Exporter);
-@EXPORT = qw(%GetInfoReturnTypes %GetInfoReturnValues);
+our @ISA = qw(Exporter);
+our @EXPORT = qw(%GetInfoReturnTypes %GetInfoReturnValues);
 
 my
-$VERSION = sprintf("2.%06d", q$Revision: 8696 $ =~ /(\d+)/o);
-
+$VERSION = "2.008697";
 
 =head1 NAME
 
@@ -41,13 +39,13 @@ use DBI::Const::GetInfoType;
 use DBI::Const::GetInfo::ANSI ();
 use DBI::Const::GetInfo::ODBC ();
 
-%GetInfoReturnTypes =
+our %GetInfoReturnTypes =
 (
   %DBI::Const::GetInfo::ANSI::ReturnTypes
 , %DBI::Const::GetInfo::ODBC::ReturnTypes
 );
 
-%GetInfoReturnValues = ();
+our %GetInfoReturnValues = ();
 {
   my $A = \%DBI::Const::GetInfo::ANSI::ReturnValues;
   my $O = \%DBI::Const::GetInfo::ODBC::ReturnValues;
